# DeepRank，一个基于列表排序的推荐算法

DeepRank: Learning to Rank with Neural Networks for Recommendation

欢迎大家引用，谢谢！

个人学术主页：[英文主页](http://http://zhouxiuze.com/ "英文主页")

原论文下载地址：

[DeepRank: Learning to Rank with Neural Networks for Recommendation](http://http://zhouxiuze.com/pub/DeepRank.pdf "pdf")

代码下载地址：https://github.com/XiuzeZhou/deeprank

目前只有当初写的 tensorflow 版本，pytorch 版本等有空会补充。

# 前言

当前，大部分推荐算法都是基于用户-商品的交互信息来预测两者之间将会产生的评分值或者是可能性。最近几年，深度学习在推荐算法中研究越来越多，但是大部分算法是 point-wise 的，还有不少 pair-wise 的，没有 list-wise 的。基于这个情况下，我们提出了一个基于 list-wise 排序的深度学习推荐算法，简称 DeepRank，即基于深度学习的排序推荐模型。

# 相关内容

基于列表排序的算法中，只有 2010 年的 ListRank-MF 算法，一个传统的矩阵分解模型。现在假设用户 [latex]u[/latex]，他有一个商品列表 [latex]l_u[/latex]，计算他曾经评价过的一个商品 [latex]i[/latex]，是排在他列表中最高位置的可能性：
[latex]
P_{l_{u}}(r_{ui})=\frac{g(r_{ui})}{\sum_{k=1}^K g(r_{uk})} 
\tag{1}
[/latex]
其中，[latex]r_{ui}[/latex] 是用户 [latex]u[/latex] 对商品 [latex]i[/latex] 的评分，[latex]K[/latex] 是用户推荐列表 [latex]l_u[/latex] 中商品的个数，即 [latex]l_u[/latex] 的长度, [latex]g(\cdot)[/latex]  是一个单调递增的函数。

然后，采用交叉熵来衡量损失：
[latex]
\mathcal L(p,q)=\sum_{i=1}^K P_{l_u} \left(r_{ui}\right)logP_{l_u}\left(f \left(p_u^Tq_i \right) \right) +\frac{\lambda}{2}(\|p\|_F^2 + \|q\|_F^2)
\tag{2}
[/latex]
其中， [latex]N[/latex] 和 [latex]M[/latex] 分别是用户和商品的数目， [latex]\lambda[/latex] 是正则项系数， [latex]p[/latex] 和 [latex]q[/latex] 分别表示用户和商品的特征向量矩阵， [latex]p_u[/latex] 和 [latex]q_i[/latex] 分别表示用户 [latex]u[/latex] 和商品 [latex]i[/latex] 的特征向量， [latex]f(\cdot)[/latex] 是 Logistic 函数, 为了限制 [latex]p_u^Tq_i[/latex] 的取值范围:
[latex]
f(x)=\frac{1}{1+exp(-x)}
[/latex]
但是，该模型存在两个问题：传统的 MF 模型缺少对数据非线性和深度特征的学习；只计算第一个商品的概率，而不是前 k 个商品的概率。

# DeepRank

为了解决 ListRank-MF 算法存在的问题，我们提出了 DeepRank。采用深度学习模型来建模，来预测未来前 k 个商品的排序情况。

## 问题定义

给定一个评分矩阵 [latex]\mathbf{R}[/latex]，其中有 [latex]N[/latex] 个用户和 [latex]M[/latex] 个商品，我们重新定义可能性矩阵：
[latex]
y_{ui}=\left\{\begin{matrix}
1, \quad 如果\ r_{ui}>0\\ 
0,\quad\quad 其他 \quad \ 
\end{matrix}\right.
[/latex]
